@@ -12,7 +12,7 @@ import base64, PIL, urllib
 import shutil
 import urllib.request as urllib2
 import pythoncom
-from installerapp import checkname
+from installerapp import namehandler
 
 installed = False
 
@@ -31,7 +31,7 @@ class InstallerGUI(Frame):
 		self.installed = False
 
 		if to_dl != "":
-			self.filename = checkname.return_filename(to_dl)
+			self.filename = namehandler.get_filename(to_dl)
 			self.installer = Installer(to_dl, self, self.filename)
 		else:
 			raise FileURLException("empty URL")
@@ -75,10 +75,10 @@ class InstallerGUI(Frame):
 					self.installer.install()
 					self.installed = True
 
-					if checkname.return_format(self.filename) == "zip":
+					if namehandler.get_format(self.filename) == "zip":
 						self.installer.unzip()
 					else:
-						self.after_installed()
+						self.installer.after_installed()
 				else:
 					pass
 			else:
@@ -119,7 +119,7 @@ class Installer(object):
 	def unzip(self):
 		try:
 			with zipfile.ZipFile(self.filename, 'r') as zip_ref:
-			    zip_ref.extractall(checkname.return_filename_without_format(self.filename))
+			    zip_ref.extractall(namehandler.get_filename_without_format(self.filename))
 			    zip_ref.close()
 
 			    self.master.waitingText['text'] = "Extracting..."
@@ -176,4 +176,5 @@ class InstallerApp(object):
 
 
 class FileURLException(Exception):
+	sys.exit(1)
 	pass
